@@ -20,11 +20,10 @@ Examples:
 
     Getting and Assigning: ::
 
-        >>> from pythonix.internals.res import unpack
         >>> data = [1, 2, 3]
-        >>> val, err = unpack(item(2)(data))
+        >>> val, err = item(2)(data).unpack()
         >>> val
         3
     
 """
-from pythonix.internals.op import where, map_over, fold, attr, item, arg
+from pythonix.internals.op import where, map_over, fold, attr, item, arg, call
